\name{cv.lars}
\alias{cv.lars}
\title{Computes K-fold cross-validated error curve for lars}
\description{
Computes the K-fold cross-validated mean squared prediction error for
lars, lasso, or forward stagewise.}
\usage{
cv.lars(x, y, K = 10, fraction = seq(from = 0, to = 1, length = 100), 
    trace = FALSE, plot.it = TRUE, se = TRUE, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{Input to lars}
  \item{y}{Input to lars}
  \item{K}{Number of folds}
  \item{fraction}{Abscissa values at which CV curve should be computed,
      as a fraction of the saturated |beta|. Default is \code{seq(from = 0, to = 1, length = 100)}}
  \item{trace}{Show computations?}
  \item{plot.it}{Plot it?}
  \item{se}{Include standard error bands?}
  \item{\dots}{Additional arguments to \code{lars}}
}
\value{
Invisibly returns a list with components (which can be plotted using \code{plotCVlars})
  \item{fraction}{As above}
  \item{cv}{The CV curve at each value of fraction}
  \item{cv.error}{The standard error of the CV curve}
}
\references{
Efron, Hastie, Johnstone and Tibshirani (2003) "Least Angle Regression"
(with discussion) \emph{Annals of Statistics}; see also
\url{http://www-stat.stanford.edu/~hastie/Papers/LARS/LeastAngle_2002.ps}.
}
\author{Trevor Hastie}
\examples{
data(diabetes)
attach(diabetes)
cv.lars(x2,y,trace=TRUE,max.steps=80)
detach(diabetes)
}
\keyword{regression}


\eof
\name{diabetes}
\alias{diabetes}
\title{Blood and other measurements in diabetics}
\description{
 The \code{diabetes} data frame has 442 rows and 3 columns.
These are the data used in the Efron et al "Least Angle Regression" paper.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{x}{a matrix with 10 columns}
    \item{y}{a numeric vector}
    \item{x2}{a matrix with 64 columns}
  }
}
\details{
The x matrix has been standardized to have unit L2 norm in each column
and zero mean. The matrix x2 consists of x plus certain interactions.
}
\source{
  \url{http://www-stat.stanford.edu/~hastie/Papers/LARS/LeastAngle_2002.ps}
  }
\references{
Efron, Hastie, Johnstone and Tibshirani (2003) "Least Angle Regression"
(with discussion) \emph{Annals of Statistics}
}
\keyword{datasets}

\eof
\name{lars-internal}
\title{Internal lars functions}
\alias{backsolvet}
\alias{cv.folds}
\alias{delcol} 
\alias{downdateR}
\alias{error.bars}
\alias{nnls.lars}
\alias{plotCVLars}
\alias{print.lars}
\alias{updateR}
\alias{.First.lib}
\description{Internal lars functions}
\usage{
backsolvet(r,x,k = ncol(r))
cv.folds(n, folds = 10)
delcol(r, z, k = p)
downdateR (R, k = p)
error.bars(x, upper, lower, width = 0.02, ...)
nnls.lars(active, Sign, R, beta, Gram, eps = 1e-10, trace = FALSE, 
    use.Gram = TRUE)
plotCVLars(cv.lars.object, se = TRUE)
updateR(xnew, R = NULL, xold, eps = .Machine$double.eps, Gram = FALSE)
.First.lib(lib, pkg)
}
\author{Trevor Hastie}
\details{
  These are not to be called by the user. \code{backsolvet} is included
  to make the R code compatible with the Splus code, since
  \code{backsolve} in R has a \code{transpose=TRUE} option already.
}
\keyword{internal}

\eof
\name{lars}
\alias{lars}
\title{
Fits Least Angle Regression, Lasso and Infinitesimal Forward Stagewise regression models
}
\description{
These are all variants of Lasso, and provide the entire sequence of
coefficients and fits, starting from zero, to the least squares fit.
}
\usage{
lars(x, y, type = c("lasso", "lar", "forward.stagewise"), 
    trace = FALSE, Gram, eps = .Machine$double.eps, max.steps, use.Gram = TRUE)
}
\arguments{
\item{x}{
matrix of predictors
}
\item{y}{
response 
}
\item{type}{
One of  "lasso", "lar"  or "forward.stagewise". The names can be abbreviated to any unique
substring. Default is "lasso".
}
\item{trace}{
If TRUE, lars prints out its progress
}
\item{Gram}{
The X'X matrix; useful for repeated runs (bootstrap) where a large X'X
stays the same.
}
\item{eps}{
An effective zero
}
\item{max.steps}{
  Limit the number of steps taken; the default is \code{8 * min(m,
    n-1)}, with m the number of variables, and n the number of samples.
  For \code{type="lar"}, the maximum number of steps is
  \code{min(m,n-1)}. For \code{type="lasso"} and especially
  \code{type="forward.stagewise"}, there can be many more terms, because
  although no more than \code{min(m,n-1)} variables can be active during
  any step, variables are frequently droppped and added as the algorithm
  proceeds. Although the default usually guarantees that the algorithm
  has proceeded to the saturated fit, users should check.
}
\item{use.Gram}{
When the number m of variables is very large, i.e. larger than N, then
you may not want LARS to precompute the Gram matrix. Default is use.Gram=TRUE
}}
\value{
A "lars" object is returned, for which print, plot and predict
methods exist.
}
\details{
LARS is described in detail in Efron, Hastie, Johnstone and Tibshirani
(2002). With the "lasso" option, it computes the complete lasso
solution simultaneously for ALL values of the shrinkage parameter in
the same computational cost as a least squares fit.
}
\references{
Efron, Hastie, Johnstone and Tibshirani (2003) "Least Angle Regression"
(with discussion) \emph{Annals of Statistics}; see also \url{http://www-stat.stanford.edu/~hastie/Papers/LARS/LeastAngle_2002.ps}.
Hastie, Tibshirani and Friedman (2002) Elements of Statistical
Learning, Springer, NY.
}
\author{Brad Efron and Trevor Hastie}
\seealso{
print, plot, and predict methods for lars, and  cv.lars
}
\examples{
data(diabetes)
par(mfrow=c(2,2))
attach(diabetes)
object <- lars(x,y)
plot(object)
object2 <- lars(x,y,type="lar")
plot(object2)
object3 <- lars(x,y,type="for") # Can use abbreviations
plot(object3)
detach(diabetes)
}
\keyword{regression}
% Converted by Sd2Rd version 1.21.



\eof
\name{plot.lars}
\alias{plot.lars}
\title{Plot method for lars objects}
\description{
Produce a plot of a lars fit. The default is a complete coefficient
path.
}
\usage{
plot.lars(x, xvar= c("norm", "df", "arc.length"), breaks = TRUE, plottype = c("coefficients", 
    "Cp"), omit.zeros = TRUE, eps = 1e-10, ...)
}
\arguments{
  \item{x}{lars object}
  \item{xvar}{The type of x variable against which to
plot. \code{xvar=norm} plots against the L1 norm of the coefficient
vector (default). \code{xvar=df} plots against the step number (which is
essentially degrees of freedom for LAR; not for LASSO or Forward
Stagewise). \code{xvar=arc.length} plots against the arc.length of the
fitted vector; this is useful for a LAR object, because the L1 norm of
its coefficient vector need not be monotone in the steps.}
  \item{breaks}{If \code{TRUE}, then vertical lines are drawn at each
      break point in the piecewise linear coefficient paths}
  \item{plottype}{Either \code{coefficients} (default) or \code{Cp}. The
      coefficient plot shows the path of each coefficient as a function
      of the norm fraction or Df. The Cp plot shows the Cp curve.}
  \item{omit.zeros}{When the number of variables  is much greater than
    the number of observations, many coefficients will never be nonzero;
      this logical (default \code{TRUE}) avoids plotting these zero coefficents}
  \item{eps}{Definition of zero above, default is \code{1e-10}}
  \item{\dots}{Additonal arguments for generic plot. Can be used to set xlims,
      change colors, line widths, etc}
}
\value{NULL}
\references{
Efron, Hastie, Johnstone and Tibshirani (2003) "Least Angle Regression"
(with discussion) \emph{Annals of Statistics}; see also
\url{http://www-stat.stanford.edu/~hastie/Papers/LARS/LeastAngle_2002.ps}
}
\author{Trevor Hastie}
\examples{
data(diabetes)
attach(diabetes)
object <- lars(x,y)
plot(object)
detach(diabetes)
}
\keyword{hplot}
\keyword{methods}

\eof
\name{predict.lars}
\alias{predict.lars}
\alias{coef.lars}
\title{
Make predictions or extract coefficients from a fitted lars model
}
\description{
While lars() produces the entire path of solutions, predict.lars
allows one to extract a prediction at a particular point along the path.
}
\usage{
predict.lars(object, newx, s, type = c("fit", "coefficients"), mode = c("step", 
    "fraction", "norm"), ...)
coef.lars(object, ...)
}
\arguments{
\item{object}{
A fitted lars object
}
\item{newx}{
If type="fit", then newx should be the x values at which the fit is
required. If type="coefficients", then newx can be omitted.
}
\item{s}{
a value, or vector of values, indexing the path. Its values depends on the mode= argument. By
default (mode="step"), s should take on values between 0 and p (e.g.,
a step of 1.3 means .3 of the way between step 1 and 2.)
}
\item{type}{
If type="fit", predict returns the fitted values. If
type="coefficients", predict returns the coefficients.
Abbreviations allowed.
}
\item{mode}{
Mode="step" means the s= argument indexes the lars step number, and
the coefficients will be returned corresponding to the values
corresponding to step s. If mode="fraction", then s should be a number
between 0 and 1, and it refers to the ratio of the L1 norm of the
coefficient vector, relative to the norm at the full LS solution.
Mode="norm" means s refers to the L1 norm of the coefficient vector.
Abbreviations allowed.
}
\item{\dots}{Any arguments for \code{predict.lars} should work for \code{coef.lars}}
}
\value{
Either a vector/matrix of fitted values, or a vector/matrix of coefficients.
}
\details{
LARS is described in detail in Efron, Hastie, Johnstone and Tibshirani
(2002). With the "lasso" option, it computes the complete lasso
solution simultaneously for ALL values of the shrinkage parameter in
the same computational cost as a least squares fit.
}
\references{
Efron, Hastie, Johnstone and Tibshirani (2002)
Hastie, Tibshirani and Friedman (2002) Elements of Statistical
Learning, Springer, NY.
}
\author{Trevor Hastie}
\seealso{
print, plot,  lars, cv.lars
}
\examples{
data(diabetes)
attach(diabetes)
object <- lars(x,y,type="lasso")
### make predictions at the values in x, at each of the
### steps produced in object
fits <- predict.lars(object, x, type="fit")
### extract the coefficient vector with L1 norm=4.1
coef4.1 <- coef(object, s=4.1, mode="norm") # or
coef4.1 <- predict(object, s=4.1, type="coef", mode="norm")
detach(diabetes)
}
\keyword{regression}
\keyword{methods}
% Converted by Sd2Rd version 1.21.

\eof
